#
# spec file for package gcolor3
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gcolor3
Version:        2.4.0
Release:        3.1
Summary:        A color chooser written in GTK3 (like gcolor2)
License:        GPL-2.0-only
Group:          Productivity/Graphics/Other
URL:            https://www.hjdskes.nl/projects/gcolor3/
Source0:        https://gitlab.gnome.org/World/gcolor3/-/archive/v%{version}/gcolor3-v%{version}.tar.bz2
Patch0:         gcolor3-suse.patch
Patch1:         gcolor-libportal-gtk3.patch
BuildRequires:  cmake
BuildRequires:  git
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libportal-gtk3) >= 0.5

%description
Gcolor3 enables picking the color from any pixel on the screen. It
also offers a palette to mix and match a couple of colors together.
Colors can be saved and retrieved.

%prep
%autosetup -p1 -n gcolor3-v%{version}

%build
%meson
%meson_build

%install
%meson_install
%find_lang gcolor3

%files -f gcolor3.lang
%license LICENSE
%doc README.md
%attr(0755,-,-) %{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/metainfo/nl.hjdskes.gcolor3.appdata.xml
%{_datadir}/applications/nl.hjdskes.gcolor3.desktop
%{_datadir}/icons/hicolor/scalable/apps/nl.hjdskes.gcolor3.svg
%{_datadir}/icons/hicolor/symbolic/apps/nl.hjdskes.gcolor3-symbolic.svg

%changelog
* Tue May  6 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Drop obsolete and unused gnome-common BuildRequires.
* Tue Apr  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Replace libportal-devel BuildRequires with
  pkgconfig(libportal-gtk3) to be more specific and not be
  dependant on package names.
- Add gcolor-libportal-gtk3.patch: Fix build against recent
  libportal, which has gtk3 and gtk4 backends.
* Mon May 17 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Use SourceUrl, fixes Factory CI scripts
* Wed Aug 26 2020 Sébastien POHER <sogal@opensuse.org>
- Upgrade to version 2.4.0
  * Color Picker now works on Wayland
  * typography and iconography changed to be consistent with GNOME HIG
  * dropped use of deprecated GTK APIs to make porting to GTK4 a smooth process
  * multiple other under-the-hood improvements
* Tue Jan 14 2020 Sébastien POHER <sogal@opensuse.org>
- Fix typo in git version
* Tue Jan 14 2020 Sébastien POHER <sogal@opensuse.org>
- Downgrade to git revision 78 as libportal is not shipped in
  Leap 15.2
* Mon Jan 13 2020 Sébastien POHER <sogal@opensuse.org>
- Upgrade to latest git commit
- Fix tag
* Fri Nov  1 2019 Sébastien POHER <sogal@opensuse.org>
- Upgrade to latest git to fix G_PARAM_PRIVATE deprecation error
- Remove uneeded -Dwerror=false meson flag
* Wed Oct 30 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Pass -Dwerror=false to meson: to not choke on deprecated APIs. It
  is not the distro's duty to catch up.
* Sat Dec 22 2018 sogal@opensuse.org
- Removed deprecated %%post and %%postun macros
- Removed uneeded Build requirement
* Sat Dec 22 2018 sogal@opensuse.org
- Update French translation, fix bad tar archive.
* Thu Dec  6 2018 Jan Engelhardt <jengelh@inai.de>
- Generalize description.
- Use %%meson_* instead of calling ninja directly.
* Wed Oct 31 2018 sogal@opensuse.org
- Use %%meson macro
- Disabled build for openSUSE Leap 42.3 as its gettext version is to
  old (the --xml switch is absent and build faild)
* Mon Oct 29 2018 sogal@opensuse.org
- Updated to 2.3.1
  * import deprecated GtkColorSelection and GtkHSV
  * fix crashing GNOME Shell on Wayland
  * port Gcolor3 to the Meson build system
  * gcolor3ColorStore: mention that warnings are harmless on first run
  * fix CTRL-C and other keyboard shortcuts
  * redesigned saved color page
  * redesigned header bar
  * add a GtkShortcutswindow
  * bumps the required version of GTK+ 3 to 3.20.
  * add a manual page
  * new translations: Norwegian Bokmål, Indonesian, Russian, Spanish
  * updated translations: Dutch, British English, German, Serbian
- Updated patch gcolor3-suse.patch
- Updated rpm structure to use %%{_datadir}/metainfo and
  newx upstream "nl.hjdskes" prefix
- Project is now hosted at gitlab.gnome.org
* Sat Jul  8 2017 sogal@volted.net
- rpmlinting
* Fri Jul  7 2017 sogal <sogal@volted.net>
- First build with git-20170322 version
  * added patch for Suse desktop file compliance
